@@ -119,9 +119,21 @@ class VerifyToken:
           permission_name = '用户列表'  # 当前视图函数所属 权限名称
           permission_status = 0  # 默认无权限, 更具获取的权限控制请求方式
         """
-        if not self.redis_connect or not self.role_db or not self.user_db:
+        if not self.redis_connect:
             handle_abnormal(
-                message='计算组件未建立连接/依赖到认证中心，无法验证权限',
+                message='计算组件未建立连接/依赖到认证中心-Redis服务，无法验证权限',
+                status=500,
+            )
+        elif not self.role_db:
+            handle_abnormal(
+                message='计算组件未建立连接/依赖到认证中心-角色集合({0})，无法验证权限'.format(
+                    self.mongo_role),
+                status=500,
+            )
+        elif not self.user_db:
+            handle_abnormal(
+                message='计算组件未建立连接/依赖到认证中心-用户集合({0})，无法验证权限'.format(
+                    self.mongo_user),
                 status=500,
             )
         permission_status = 0
